@@ -14,32 +14,32 @@
 /* ecbuild info */
 
 #ifndef ECBUILD_VERSION_STR
-#define ECBUILD_VERSION_STR "3.11.0"
+#define ECBUILD_VERSION_STR "3.12.0"
 #endif
 #ifndef ECBUILD_VERSION
-#define ECBUILD_VERSION "3.11.0"
+#define ECBUILD_VERSION "3.12.0"
 #endif
 #ifndef ECBUILD_MACROS_DIR
-#define ECBUILD_MACROS_DIR  "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/eccodes-2.42.0-Source/cmake"
+#define ECBUILD_MACROS_DIR  "/opt/local/var/macports/build/ecCodes-5968d902/work/eccodes-2.44.0-Source/cmake"
 #endif
 
 /* config info */
 
-#define ECCODES_OS_NAME          "Darwin-24.3.0"
+#define ECCODES_OS_NAME          "Darwin-24.6.0"
 #define ECCODES_OS_BITS          64
 #define ECCODES_OS_BITS_STR      "64"
 #define ECCODES_OS_STR           "macosx.64"
-#define ECCODES_OS_VERSION       "24.3.0"
+#define ECCODES_OS_VERSION       "24.6.0"
 #define ECCODES_SYS_PROCESSOR    "x86_64"
 
-#define ECCODES_BUILD_TIMESTAMP  "20250701115638"
+#define ECCODES_BUILD_TIMESTAMP  "20251007213706"
 #define ECCODES_BUILD_TYPE       "Release"
 
 #define ECCODES_C_COMPILER_ID      "AppleClang"
-#define ECCODES_C_COMPILER_VERSION "16.0.0.16000026"
+#define ECCODES_C_COMPILER_VERSION "17.0.0.17000319"
 
 #define ECCODES_CXX_COMPILER_ID      "AppleClang"
-#define ECCODES_CXX_COMPILER_VERSION "16.0.0.16000026"
+#define ECCODES_CXX_COMPILER_VERSION "17.0.0.17000319"
 
 #define ECCODES_C_COMPILER       "/usr/bin/clang"
 #define ECCODES_C_FLAGS          "-pipe -Os -DNDEBUG -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk -pipe -O3 -DNDEBUG"
@@ -54,17 +54,17 @@
 #define ECCODES_INSTALL_LIB_DIR   "/opt/local/lib"
 #define ECCODES_INSTALL_DATA_DIR  "/opt/local/share/eccodes"
 
-#define ECCODES_DEVELOPER_SRC_DIR "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/eccodes-2.42.0-Source"
-#define ECCODES_DEVELOPER_BIN_DIR "/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_science_ecCodes/ecCodes/work/build"
+#define ECCODES_DEVELOPER_SRC_DIR "/opt/local/var/macports/build/ecCodes-5968d902/work/eccodes-2.44.0-Source"
+#define ECCODES_DEVELOPER_BIN_DIR "/opt/local/var/macports/build/ecCodes-5968d902/work/build"
 
 /* Fortran support */
 
 #if 1
 
 #define ECCODES_Fortran_COMPILER_ID      "GNU"
-#define ECCODES_Fortran_COMPILER_VERSION "14.2.0"
+#define ECCODES_Fortran_COMPILER_VERSION "15.1.0"
 
-#define ECCODES_Fortran_COMPILER "/opt/local/bin/gfortran-mp-14"
+#define ECCODES_Fortran_COMPILER "/opt/local/bin/gfortran-mp-15"
 #define ECCODES_Fortran_FLAGS    "-pipe -Os -fallow-argument-mismatch -m64 -O3 -DNDEBUG -funroll-all-loops -finline-functions"
 
 #endif
